summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouch.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'ktouch/src/ktouch.cpp')
-rw-r--r--ktouch/src/ktouch.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/ktouch/src/ktouch.cpp b/ktouch/src/ktouch.cpp
index 85900c15..6c9a78c8 100644
--- a/ktouch/src/ktouch.cpp
+++ b/ktouch/src/ktouch.cpp
@@ -179,10 +179,10 @@ void KTouch::keyPressEvent(TQKeyEvent *keyEvent) {
if (keyEvent->text().length() > 1) {
kdDebug() << "[KTouch::keyPressEvent] text = '" << TQString(keyEvent->text()).ascii() << "'" << endl;
}
- TQChar key = keyEvent->text().at(0); // get first tqunicode character
+ TQChar key = keyEvent->text().at(0); // get first unicode character
// HACK : manually filter out known dead keys
// bool has_dead_key = true;
- switch (key.tqunicode()) {
+ switch (key.unicode()) {
case 94 : m_lastDeadKey = TQChar(uint(94)); break;
case 176 : m_lastDeadKey = TQChar(uint(176)); break;
case 180 : m_lastDeadKey = TQChar(uint(180)); break;
@@ -468,9 +468,9 @@ void KTouch::changeStatusbarStats(unsigned int level_correct, unsigned int level
void KTouch::changeKeyboard(int num) {
if (static_cast<unsigned int>(num)>=m_keyboardFiles.count()) return;
Prefs::setCurrentKeyboardFile( m_keyboardFiles[num] );
-// kdDebug() << "[KTouch::changeKeyboard] new keyboard tqlayout = " << Prefs::currentKeyboardFile() << endl;
+// kdDebug() << "[KTouch::changeKeyboard] new keyboard layout = " << Prefs::currentKeyboardFile() << endl;
m_keyboardLayoutAction->setCurrentItem(num);
- // call Apply-Preferenzes in "noisy"-mode, pop up an error if the chosen tqlayout file is corrupt
+ // call Apply-Preferenzes in "noisy"-mode, pop up an error if the chosen layout file is corrupt
m_keyboardWidget->applyPreferences(this, false);
}
// ----------------------------------------------------------------------------
@@ -620,8 +620,8 @@ void KTouch::init() {
*/
}
- // if keyboard tqlayout (loaded by Prefs is not available (e.g. the
- // tqlayout file has been deleted) switch to default keyboard
+ // if keyboard layout (loaded by Prefs is not available (e.g. the
+ // layout file has been deleted) switch to default keyboard
if (m_keyboardFiles.contains(Prefs::currentKeyboardFile() )==0) {
TQString default_keyboard;
// determine locale
@@ -652,7 +652,7 @@ void KTouch::init() {
}
// ----------------------------------------------------------------------------
-// Creates the tqlayout and GUI setup for a practice session
+// Creates the layout and GUI setup for a practice session
void KTouch::initTrainingSession() {
//kdDebug() << "[KTouch::initTrainingSession] setting up layouts and widgets for new training session..." << endl;
// Build the training area. The status widget has a fixed vertical size, the slide line and the
@@ -753,7 +753,7 @@ void KTouch::updateFileLists() {
// TODO : search in i18n() directories
m_keyboardFiles = dirs->findAllResources("data","ktouch/*.keyboard");
- // remove the number tqlayout, since this is the necessary default tqlayout and will be
+ // remove the number layout, since this is the necessary default layout and will be
// added anyway
TQStringList::iterator it = m_keyboardFiles.find("number.keyboard");
if (it!=m_keyboardFiles.end()) m_keyboardFiles.remove(it);